Experimental support for ipywidgets inside a flask server. This package is based on https://github.com/pbugnion/ipywidgets_server which is a standalone server, created by Pascal Bugnion.

Install:
```
$ git clone https://github.com/maartenbreddels/flask-ipywidgets
$ pip install flask-ipywidgets
```

Run example:
```
$ python -m flask_ipywidgets.example1
$ # or python -m flask_ipywidgets.example2
```
And navigate to http://localhost:5000